@@ -78,7 +78,7 @@
 #' as the maximum background integral for the Tx curve.
 #'
 #' @param rejection.criteria \code{\link{list}} (with default): provide a named list
-#' and set rejection criteria in percentage for further calculation. Can be a \code{\link{list}} in
+#' and set rejection criteria in \bold{percentage} for further calculation. Can be a \code{\link{list}} in
 #' a \code{\link{list}}, if \code{object} is of type \code{\link{list}}
 #'
 #' Allowed arguments are \code{recycling.ratio}, \code{recuperation.rate},
@@ -133,7 +133,7 @@
 #'
 #' \bold{The function currently does only support 'OSL' or 'IRSL' data!}
 #'
-#' @section Function version: 0.7.5
+#' @section Function version: 0.7.9
 #'
 #' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne
 #' (France)
@@ -287,7 +287,7 @@ if(is.list(object)){
   ##merge results and check if the output became NULL
   results <- merge_RLum(temp)
 
-  ##DO NOT use invisible here, this will stop the function from stopping
+  ##DO NOT use invisible here, this will prevent the function from stopping
   if(length(results) == 0){
     return(NULL)
 
@@ -416,6 +416,20 @@ if(is.list(object)){
 
     ##modify list on the request
     if(!is.null(rejection.criteria)){
+
+      ##check if the provided values are valid at all
+      if(!all(names(rejection.criteria)%in%names(rejection.criteria.default))){
+        try(stop(
+          paste0("[analyse_SAR.CWOSL()] Rejection criteria '",
+                paste(
+                  names(
+                    rejection.criteria)[
+                      !names(rejection.criteria)%in%names(rejection.criteria.default)], collapse = ", ")
+                       ,"' unknown! Input ignored!"), call. = FALSE))
+
+      }
+
+      ##modify list
       rejection.criteria <- modifyList(rejection.criteria.default, rejection.criteria)
 
     }else{
@@ -597,12 +611,13 @@ if(is.list(object)){
 
     ##separate TL curves
     TL.Curves.ID.Lx <-
-      sapply(1:length(OSL.Curves.ID.Lx), function(x) {
+      lapply(1:length(OSL.Curves.ID.Lx), function(x) {
         TL.Curves.ID[which(TL.Curves.ID == (OSL.Curves.ID.Lx[x] - 1))]
       })
 
+
     TL.Curves.ID.Tx <-
-      sapply(1:length(OSL.Curves.ID.Tx), function(x) {
+      lapply(1:length(OSL.Curves.ID.Tx), function(x) {
         TL.Curves.ID[which(TL.Curves.ID == (OSL.Curves.ID.Tx[x] - 1))]
       })
 
@@ -844,18 +859,19 @@ if(is.list(object)){
         })
 
     }else{
-      temp.status.RecyclingRatio <- "OK"
+      temp.status.RecyclingRatio <- rep("OK", length(RecyclingRatio))
 
     }
 
     ##Recuperation
-    if (!is.na(Recuperation)[1] & !is.na(rejection.criteria$recuperation.rate)) {
+    if (!is.na(Recuperation)[1] &
+        !is.na(rejection.criteria$recuperation.rate)) {
       temp.status.Recuperation  <-
         sapply(1:length(Recuperation), function(x) {
-          if(Recuperation[x] > rejection.criteria$recuperation.rate){
+          if (Recuperation[x] > rejection.criteria$recuperation.rate / 100) {
             "FAILED"
 
-          }else{
+          } else{
             "OK"
 
           }
@@ -867,6 +883,7 @@ if(is.list(object)){
 
     }
 
+
     # Provide Rejection Criteria for Testdose error --------------------------
     testdose.error.calculated <- (LnLxTnTx$Net_TnTx.Error/LnLxTnTx$Net_TnTx)[1]
 
@@ -990,12 +1007,12 @@ if(is.list(object)){
         if (length(TL.Curves.ID.Lx[[1]] > 0)) {
           ##It is just an approximation taken from the data
           resolution.TLCurves <-  round(mean(diff(
-            round(object@records[[TL.Curves.ID.Lx[1]]]@data[,1], digits = 1)
+            round(object@records[[TL.Curves.ID.Lx[[1]]]]@data[,1], digits = 1)
           )), digits = 1)
 
           ylim.range <-
             sapply(seq(1,length(TL.Curves.ID.Lx),by = 1) ,function(x) {
-              range(object@records[[TL.Curves.ID.Lx[x]]]@data[,2])
+              range(object@records[[TL.Curves.ID.Lx[[x]]]]@data[,2])
 
             })
 
@@ -1004,8 +1021,8 @@ if(is.list(object)){
             xlab = "T [\u00B0C]",
             ylab = paste("TL [cts/",resolution.TLCurves," \u00B0C]",sep =
                            ""),
-            xlim = c(object@records[[TL.Curves.ID.Lx[1]]]@data[1,1],
-                     max(object@records[[TL.Curves.ID.Lx[1]]]@data[,1])),
+            xlim = c(object@records[[TL.Curves.ID.Lx[[1]]]]@data[1,1],
+                     max(object@records[[TL.Curves.ID.Lx[[1]]]]@data[,1])),
             ylim = c(1,max(ylim.range)),
             main = main,
             log = if (log == "y" | log == "xy") {
@@ -1024,7 +1041,7 @@ if(is.list(object)){
 
           ##plot TL curves
           sapply(1:length(TL.Curves.ID.Lx) ,function(x) {
-            lines(object@records[[TL.Curves.ID.Lx[x]]]@data,col = col[x])
+            lines(object@records[[TL.Curves.ID.Lx[[x]]]]@data,col = col[x])
 
           })
 
@@ -1132,12 +1149,12 @@ if(is.list(object)){
         if (length(TL.Curves.ID.Tx[[1]] > 0)) {
           ##It is just an approximation taken from the data
           resolution.TLCurves <-  round(mean(diff(
-            round(object@records[[TL.Curves.ID.Tx[1]]]@data[,1], digits = 1)
+            round(object@records[[TL.Curves.ID.Tx[[1]]]]@data[,1], digits = 1)
           )), digits = 1)
 
 
           ylim.range <- sapply(1:length(TL.Curves.ID.Tx) ,function(x) {
-            range(object@records[[TL.Curves.ID.Tx[x]]]@data[,2])
+            range(object@records[[TL.Curves.ID.Tx[[x]]]]@data[,2])
 
           })
 
@@ -1147,8 +1164,8 @@ if(is.list(object)){
             NA,NA,
             xlab = "T [\u00B0C]",
             ylab = paste("TL [cts/",resolution.TLCurves," \u00B0C]",sep = ""),
-            xlim = c(object@records[[TL.Curves.ID.Tx[1]]]@data[1,1],
-                     max(object@records[[TL.Curves.ID.Tx[1]]]@data[,1])),
+            xlim = c(object@records[[TL.Curves.ID.Tx[[1]]]]@data[1,1],
+                     max(object@records[[TL.Curves.ID.Tx[[1]]]]@data[,1])),
             ylim = c(1,max(ylim.range)),
             main = main,
             log = if (log == "y" | log == "xy") {
@@ -1167,7 +1184,7 @@ if(is.list(object)){
 
           ##plot TL curves
           sapply(1:length(TL.Curves.ID.Tx) ,function(x) {
-            lines(object@records[[TL.Curves.ID.Tx[x]]]@data,col = col[x])
+            lines(object@records[[TL.Curves.ID.Tx[[x]]]]@data,col = col[x])
 
           })
 
@@ -1677,7 +1694,6 @@ if(is.list(object)){
     }
 
 
-
     # Return --------------------------------------------------------------------------------------
     invisible(temp.results.final)
 
@@ -1691,3 +1707,5 @@ if(is.list(object)){
   }
 
 }
+
+
